**************************************
* This program creates Table 4
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Table 4. 2009-12 Panel of Forecasts
*****************************************

preserve
* Settings
local title = "2009-10 to 2012-13"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval yyyy = 1997/2012 {
	local year = `yyyy'+1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`yyyy'spring/100)*(1+ngdp_rpch`yyyy'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`yyyy'spring-ggsb_gdp`yyyy'spring[_n-2] if year==`year' & x==.
}
* Sample:
keep if sample==1
* Regression:
reg y x i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x using T4.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	replace
restore

* 2009-2012 sample: individual years
preserve
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval yyyy = 1997/2012 {
	local year = `yyyy'+1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`yyyy'spring/100)*(1+ngdp_rpch`yyyy'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`yyyy'spring-ggsb_gdp`yyyy'spring[_n-2] if year==`year' & x==.
}
* Sample:
keep if sample==1
* Regression:
reg y x if year==2010, r
* Store results in outreg table
	outreg2 x using T4.xls, ///
	ctitle("2009-10") bdec(3) ///
	append
* Regression:
reg y x if year==2011, r
* Store results in outreg table
	outreg2 x using T4.xls, ///
	ctitle("2010-11") bdec(3) ///
	append
* Regression:
reg y x if year==2012, r
* Store results in outreg table
	outreg2 x using T4.xls, ///
	ctitle("2011-12") bdec(3) ///
	append
* Regression:
reg y x if year==2013, r
* Store results in outreg table
	outreg2 x using T4.xls, ///
	ctitle("2012-13") bdec(3) ///
	append
restore

* Precrisis sample
preserve
* Settings
local title = "1997-98 to 2008-09"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval yyyy = 1997/2012 {
	local year = `yyyy'+1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`yyyy'spring/100)*(1+ngdp_rpch`yyyy'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`yyyy'spring-ggsb_gdp`yyyy'spring[_n-2] if year==`year' & x==.
}
* Sample:
keep if sample==1
* Regression:
reg y x i.year if year>=1997 & year<=2009, r
local r2 = e(r2)
newey y x i.year if year>=1997 & year<=2009, lag(1) force
* Store results in outreg table
	outreg2 x using T4.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "All advanced"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval yyyy = 1997/2012 {
	local year = `yyyy'+1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`yyyy'spring/100)*(1+ngdp_rpch`yyyy'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`yyyy'spring-ggsb_gdp`yyyy'spring[_n-2] if year==`year' & x==.
}
* Regression:
keep if (eu==1|weoadv==1)
reg y x i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x using T4.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Economies in liquidity trap"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval yyyy = 1997/2012 {
	local year = `yyyy'+1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`yyyy'spring/100)*(1+ngdp_rpch`yyyy'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`yyyy'spring-ggsb_gdp`yyyy'spring[_n-2] if year==`year' & x==.
}
* Regression:
keep if (eu==1|weoadv==1)
drop if (wdicode=="AUS"|wdicode=="HKG"|wdicode=="HUN"|wdicode=="ISL"|wdicode=="ISR"|wdicode=="KOR"|wdicode=="NZL"|wdicode=="NOR"|wdicode=="POL"|wdicode=="ROM"|wdicode=="SGP"|wdicode=="SWE"|wdicode=="TWN")
reg y x i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x using T4.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Emerging market economies"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval yyyy = 1997/2012 {
	local year = `yyyy'+1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`yyyy'spring/100)*(1+ngdp_rpch`yyyy'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`yyyy'spring-ggsb_gdp`yyyy'spring[_n-2] if year==`year' & x==.
}
* Regression:
keep if (eu~=1 & weoadv~=1)
reg y x i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x using T4.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore


log close

