**************************************
* This program creates Appendix Table 2
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Appendix Table 2. All Advanced Economies: Robustness to Additional Controls
* Column 1: OLS Regression
*****************************************

* Set up sample
cap drop sample
gen sample=1 if (eu==1|weoadv==1)

preserve
* Settings
local title = "Baseline"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 1
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "Initial debt ratio"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = gd_GDP2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial fiscal balance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = ggxcnl_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial structural fiscal balance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial sovereign CDS"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (sovcds_q1av[_n-1])/100
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial bank CDS"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux1 = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux2 = (sovcds_q1av[_n-1])/100
rreg aux1 aux2 i.year if sample==1 & year>=2009 & year<=2011
predict yhat
bys ifscode: replace z = yhat if z==.
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Banking crisis"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 0
bys ifscode: replace z = bankcrisis
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial growth forecast"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial potential growth forecast"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1) - (ngap2010spring-ngap2010spring[_n-2])
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Trading partner fiscal consolidation"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (xggsb_gdp2010spring-xggsb_gdp2010spring[_n-2])*(nx_r2010spring[_n-2]/ngdp_r2010spring[_n-2]) 
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis current account balance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = bca_gdp2010spring[_n-4]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis net foreign liabilities"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = -nfa[_n-4]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis household debt"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = dti[_n-4]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z, r
* Store results in outreg table
	outreg2 using TA2_OLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

*****************************************
* Appendix Table 2. All Advanced Economies: Robustness to Additional Controls
* Column 2: Robust Regression
*****************************************

* Set up sample
cap drop sample
gen sample=1 if (eu==1|weoadv==1)

* Settings
local title = "Baseline: weights"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Regression
rreg y x if year==2011 & sample==1, genwt(w)
cap drop y x
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	replace

preserve
* Settings
local title = "Initial debt ratio"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = gd_GDP2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial fiscal balance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = ggxcnl_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial structural fiscal balance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial sovereign CDS"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (sovcds_q1av[_n-1])/100
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial bank CDS"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux1 = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux2 = (sovcds_q1av[_n-1])/100
rreg aux1 aux2 i.year if sample==1 & year>=2009 & year<=2011
predict yhat
bys ifscode: replace z = yhat if z==.
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Banking crisis"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 0
bys ifscode: replace z = bankcrisis
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial growth forecast"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial potential growth forecast"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = 100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1) - (ngap2010spring-ngap2010spring[_n-2])
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Trading partner fiscal consolidation"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = (xggsb_gdp2010spring-xggsb_gdp2010spring[_n-2])*(nx_r2010spring[_n-2]/ngdp_r2010spring[_n-2]) 
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis current account balance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = bca_gdp2010spring[_n-4]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis net foreign liabilities"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = -nfa[_n-4]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis household debt"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Additional control
bys ifscode: gen z = dti[_n-4]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x z [aweight=w], r
* Store results in outreg table
	outreg2 using TA2_WLS.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

log close



