**************************************
* This program creates Appendix Table 3
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Appendix Table 3. Europe: 2009-12 Panel of Forecasts, 
* Robustness to Additional Controls
*****************************************

* Panel regression, additional controls
preserve
* Settings
local title = "Baseline"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "Initial debt ratio"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z = gd_GDP`year_m1'spring[_n-2] if year==`year'
	cap bys ifscode: replace z = gd_GDP`year'spring[_n-2] if year==`year' & z==.
}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial fiscal balance"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z = ggxcnl_gdp`year_m1'spring[_n-2] if year==`year'
	cap bys ifscode: replace z = ggxcnl_gdp`year'spring[_n-2] if year==`year' & z==.
}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial structural fiscal balance"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z = ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial sovereign CDS"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	}
bys ifscode: replace z = (sovcds_q1av[_n-1])/100
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial bank CDS"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	}
* Sample:
keep if sample==1
bys ifscode: replace z = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux1 = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux2 = (sovcds_q1av[_n-1])/100
rreg aux1 aux2 i.year if year>=2009 & year<=2011
predict yhat
bys ifscode: replace z = yhat if z==.
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore


preserve
* Settings
local title = "Banking crisis"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	}
bys ifscode: replace z = 0
bys ifscode: replace z = bankcrisis
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial growth forecast"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z = 100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Initial potential growth forecast"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z = 100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) - (ngap`year_m1'spring-ngap`year_m1'spring[_n-2]) if year==`year'
	}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Trading partner fiscal consolidation"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z = (xggsb_gdp`year_m1'spring-xggsb_gdp`year_m1'spring[_n-2])*(nx_r`year_m1'spring[_n-2]/ngdp_r`year_m1'spring[_n-2]) if year==`year'
	}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis current account balance"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	local precrisislag = `year'-2007
	bys ifscode: replace z = bca_gdp`year_m1'spring[_n-`precrisislag'] if year==`year'
	cap bys ifscode: replace z = bca_gdp`year'spring[_n-`precrisislag'] if year==`year' & z==.
}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis net foreign liabilities"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	local precrisislag = `year'-2007
	bys ifscode: replace z = -nfa[_n-`precrisislag'] if year==`year'
	}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Precrisis household debt"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
bys ifscode: gen z = 1
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	local precrisislag = `year'-2007
	bys ifscode: replace z = dti[_n-`precrisislag'] if year==`year'
	}
* Sample:
keep if sample==1
* Regression:
reg y x z i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "OLS"
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
forval i = 1/12 {
bys ifscode: gen z`i' = `i'
}
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	* Additional controls
	bys ifscode: replace z1 = gd_GDP`year_m1'spring[_n-2] if year==`year'
	cap bys ifscode: replace z1 = gd_GDP`year'spring[_n-2] if year==`year' & z1==.
	bys ifscode: replace z2 = ggxcnl_gdp`year_m1'spring[_n-2] if year==`year'
	cap bys ifscode: replace z2 = ggxcnl_gdp`year'spring[_n-2] if year==`year' & z2==.
	bys ifscode: replace z3 = ggsb_gdp`year_m1'spring[_n-2] if year==`year'
	bys ifscode: replace z6 = 0
	bys ifscode: replace z6 = bankcrisis
	bys ifscode: replace z7 = 100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'	
	bys ifscode: replace z8 = 100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) - (ngap`year_m1'spring-ngap`year_m1'spring[_n-2]) if year==`year'
	bys ifscode: replace z9 = (xggsb_gdp`year_m1'spring-xggsb_gdp`year_m1'spring[_n-2])*(nx_r`year_m1'spring[_n-2]/ngdp_r`year_m1'spring[_n-2]) if year==`year'	
	local precrisislag = `year'-2007
	bys ifscode: replace z10 = bca_gdp`year_m1'spring[_n-`precrisislag'] if year==`year'
	cap bys ifscode: replace z10 = bca_gdp`year'spring[_n-`precrisislag'] if year==`year' & z10==.
	bys ifscode: replace z11 = -nfa[_n-`precrisislag'] if year==`year'
	bys ifscode: replace z12 = dti[_n-`precrisislag'] if year==`year'
	bys ifscode: gen d`year' = 0
	bys ifscode: replace d`year' = 1 if year==`year'
}
bys ifscode: replace z4 = (sovcds_q1av[_n-1])/100
bys ifscode: replace z5 = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux1 = (bankcds_q1av[_n-1])/100
bys ifscode: gen aux2 = (sovcds_q1av[_n-1])/100
rreg aux1 aux2 i.year if year>=2009 & year<=2011
predict yhat
bys ifscode: replace z5 = yhat if z5==.
* Sample:
keep if sample==1
* Regression
reg y x z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11 z12 i.year if year>=2010 & year<=2013, r
local r2 = e(r2)
newey y x z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11 z12 i.year if year>=2010 & year<=2013, lag(1) force
* Store results in outreg table
	outreg2 x z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11 z12 using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
* Robust regression
local title = "Robust regression"
rreg y x z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11 z12 i.year if year>=2010 & year<=2013, genwt(w)
local r2 = e(r2)
newey y x z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11 z12 i.year if year>=2010 & year<=2013 [aweight=w], lag(1) force
* Store results in outreg table
	outreg2 x z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11 z12 using TA3.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore


log close

